/* 
   orxonox - the future of 3D-vertical-scrollers

   Copyright (C) 2004 orx

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software Foundation,
   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  


   ### File Specific:
   main-programmer: Benjamin Grauer

*/

#include "orxonox_gui_keys.h"
#include <iostream.h>

/**
   \brief Creates an Keyboard-Frame
*/
OrxonoxGuiKeys::OrxonoxGuiKeys ()
{
  keysFrame = new Frame ("Keyboard-Options:");
  keysFrame->setGroupName("Keyboard");
  keysBox = new Box ('v');
  player1 = new Player("player1");
  //  player2 = new Player("player2");

  keysBox->fill(player1->getOpenButton());

  keysFrame->fill (keysBox);
}

/**
   \brief Return the Frame
   \return Returns the Audio-frame
*/
Widget* OrxonoxGuiKeys::getWidget ()
{
  return keysFrame;
}



/* PLAYER */
Player::Player(char* player)
{
  openButton = new Button (player);
  openButton->connectSignal("button_press_event", this, openWindowEvent);

  keyWindow = new Window("keys of player");

  keysBox = new Box('v');
  keysBox->fill(addKey(UP, "up"));
  keysBox->fill(addKey(DOWN, "down"));
  keysBox->fill(addKey(LEFT, "left"));
  keysBox->fill(addKey(RIGHT, "right"));
  keysBox->fill(addKey(SHOOT, "shoot"));
  keyWindow->fill(keysBox);
  windowIsOpen = false;

}

Widget* Player::addKey (KEYS key, char* name)
{
  keyBox[key] = new Box();
  keyButton[key] = new Button(name);
  keyLabel[key] = new Label ("test");
  
  keyButton[key]->connectSignal("key_press_event", keyLabel[key], key_cb);
  
  keyBox[key]->fill(keyButton[key]);
  keyBox[key]->fill(keyLabel[key]);
  return keyBox[key];
}

Button* Player::getOpenButton()
{
  return openButton;
}


void Player::setkey(KEYS key)
{
  cout << "setting up Key: "<< key <<endl;

}

/**
   \brief function to display, hide the palyer window
   Buggy, segmentation fault on WindowMaker
*/
void Player::openWindow ()
{
  if (!windowIsOpen)
    keyWindow->showall();
  else
    keyWindow->hide();
  windowIsOpen = !windowIsOpen;
}

gint Player::openWindowEvent (GtkWidget* widget, GdkEvent* event, void* player)
{

  static_cast<Player*>(player)->openWindow();
}


/**
   \brief Function which gets keystrokes
   \param w the widget that released the Function.
   \param event The event that happened.
   \param Widget the Widget which will be applied.
   \returns Nothing
*/
gint Player::key_cb(GtkWidget* w, GdkEventKey* event, void* widget)
{
  Label* label = static_cast<Label*>(widget);

  switch(event->keyval) {
  case GDK_Up:
    printf("Up arrow key!\n");
    label->setText("up");
    break;
  case GDK_Down:
    printf("Down arrow key!\n");
    label->setText("down");
    break;
  case GDK_Left:
    printf("Left arrow key!\n");
    label->setText("left");
    break;
  case GDK_Right:
    printf("Right arrow key!\n");
    label->setText("right");
    break;

  case GDK_space:
    printf("Space Pressed.\n");
    label->setText("space");
    break;

  case 65293:
    printf("Enter Pressed\n");
    label->setText("enter");
    break;

    // Special Keys //
  case GDK_Shift_L:
    printf("Left Shift!\n");
    label->setText("l_shift");
    break;
  case GDK_Shift_R:
    printf("Right Shift!\n");
    label->setText("r_shift");
    break;
  case GDK_Control_L:
    printf("Left Control!\n");
    label->setText("l_ctrl");
    break;
  case GDK_Control_R:
    printf("Right Control!\n");
    label->setText("r_ctrl");
    break;
  case GDK_Alt_L:
    printf("Left Alt!\n");
    label->setText("l_alt");
    break;
  case GDK_Alt_R:
    printf("Rigth Alt!\n");
    label->setText("r_alt");
    break;
    // FXX KEYS //
  case GDK_F1:
    printf("F1!\n");
    label->setText("f1");
    break;
  case GDK_F2:
    printf("F2!\n");
    label->setText("f2");
    break;
  case GDK_F3:
    printf("F3!\n");
    label->setText("f3");
    break;
  case GDK_F4:
    printf("F4!\n");
    label->setText("f4");
    break;
  case GDK_F5:
    printf("F5!\n");
    label->setText("f5");
    break;
  case GDK_F6:
    printf("F6!\n");
    label->setText("f6");
    break;
  case GDK_F7:
    printf("F7!\n");
    label->setText("f7");
    break;
  case GDK_F8:
    printf("F8!\n");
    label->setText("f8");
    break;
  case GDK_F9:
    printf("F9\n");
    label->setText("f9");
    break;
  case GDK_F10:
    printf("F10!\n");
    label->setText("f10");
    break;
  case GDK_F11:
    printf("F11!\n");
    label->setText("f11");
    break;
  case GDK_F12:
    printf("F12!\n");
    label->setText("f12");
    break;


  default:
    char* tmp;
    sprintf(tmp, "%c", event->keyval);
    printf ("other key %s \n", tmp);
    label->setText(tmp);
    break;
  }
}
